@@ -294,23 +294,23 @@ val rcontains_from : t -> int -> char -> bool
     Raise [Invalid_argument] if [stop < 0] or [stop+1] is not a valid
     position in [s]. *)
 
-val uppercase : t -> t
-(** Return a copy of the argument, with all lowercase letters
-    translated to uppercase, including accented letters of the ISO
-    Latin-1 (8859-1) character set. *)
+# 297 "src/batBytes.mliv"
+# 298 "src/batBytes.mliv"
+# 299 "src/batBytes.mliv"
+# 300 "src/batBytes.mliv"
 
-val lowercase : t -> t
-(** Return a copy of the argument, with all uppercase letters
-    translated to lowercase, including accented letters of the ISO
-    Latin-1 (8859-1) character set. *)
+# 302 "src/batBytes.mliv"
+# 303 "src/batBytes.mliv"
+# 304 "src/batBytes.mliv"
+# 305 "src/batBytes.mliv"
 
-val capitalize : t -> t
-(** Return a copy of the argument, with the first byte set to
-    uppercase. *)
+# 307 "src/batBytes.mliv"
+# 308 "src/batBytes.mliv"
+# 309 "src/batBytes.mliv"
 
-val uncapitalize : t -> t
-(** Return a copy of the argument, with the first byte set to
-    lowercase. *)
+# 311 "src/batBytes.mliv"
+# 312 "src/batBytes.mliv"
+# 313 "src/batBytes.mliv"
 
 val uppercase_ascii : t -> t
 (** Return a copy of the argument, with all lowercase letters
@@ -768,4 +768,4 @@ external unsafe_fill:  t -> int -> int -> char -> unit = "caml_fill_bytes" [@@no
 
 external unsafe_blit_string : string -> int -> t -> int -> int -> unit = "caml_blit_string" [@@noalloc]
 
-# 771 "src/batBytes.mliv"
+val unsafe_escape : bytes -> bytes
