@@ -20,7 +20,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *)
 
-# 23 "src/batFloat.mliv"
+module Pervasives := Stdlib
 
 (**Operations on floating-point numbers.
 
