@@ -22,7 +22,7 @@
 
 open BatIO
 
-# 25 "src/batFormat.mliv"
+ module Pervasives := Stdlib
 
 (** Pretty printing.
 
@@ -331,17 +331,17 @@ type tag = string
     Tag marking and tag printing functions are user definable and can
     be set by calling [set_formatter_tag_functions]. *)
 
-val open_tag : tag -> unit
-(** [open_tag t] opens the tag named [t]; the [print_open_tag]
-    function of the formatter is called with [t] as argument;
-    the tag marker [mark_open_tag t] will be flushed into the output
-    device of the formatter. *)
+# 334 "src/batFormat.mliv"
+# 335 "src/batFormat.mliv"
+# 336 "src/batFormat.mliv"
+# 337 "src/batFormat.mliv"
+# 338 "src/batFormat.mliv"
 
-val close_tag : unit -> unit
-(** [close_tag ()] closes the most recently opened tag [t].
-    In addition, the [print_close_tag] function of the formatter is called
-    with [t] as argument. The marker [mark_close_tag t] will be flushed
-    into the output device of the formatter. *)
+# 340 "src/batFormat.mliv"
+# 341 "src/batFormat.mliv"
+# 342 "src/batFormat.mliv"
+# 343 "src/batFormat.mliv"
+# 344 "src/batFormat.mliv"
 
 val set_tags : bool -> unit
 (** [set_tags b] turns on or off the treatment of tags (default is off). *)
@@ -388,76 +388,76 @@ val get_formatter_output_functions :
     how to handle indentation, line breaking, and even printing of all the
     characters that have to be printed! *)
 
-val set_all_formatter_output_functions :
-  out:(string -> int -> int -> unit) ->
-  flush:(unit -> unit) ->
-  newline:(unit -> unit) ->
-  spaces:(int -> unit) ->
-  unit
+# 391 "src/batFormat.mliv"
+# 392 "src/batFormat.mliv"
+# 393 "src/batFormat.mliv"
+# 394 "src/batFormat.mliv"
+# 395 "src/batFormat.mliv"
+# 396 "src/batFormat.mliv"
 
-(** [set_all_formatter_output_functions out flush outnewline outspace]
-    redirects the pretty-printer output to the functions [out] and
-    [flush] as described in [set_formatter_output_functions]. In
-    addition, the pretty-printer function that outputs a newline is set
-    to the function [outnewline] and the function that outputs
-    indentation spaces is set to the function [outspace].
+# 398 "src/batFormat.mliv"
+# 399 "src/batFormat.mliv"
+# 400 "src/batFormat.mliv"
+# 401 "src/batFormat.mliv"
+# 402 "src/batFormat.mliv"
+# 403 "src/batFormat.mliv"
+# 404 "src/batFormat.mliv"
+# 405 "src/batFormat.mliv"
+# 406 "src/batFormat.mliv"
+# 407 "src/batFormat.mliv"
+# 408 "src/batFormat.mliv"
+# 409 "src/batFormat.mliv"
+# 410 "src/batFormat.mliv"
+# 411 "src/batFormat.mliv"
 
-    This way, you can change the meaning of indentation (which can be
-    something else than just printing space characters) and the
-    meaning of new lines opening (which can be connected to any other
-    action needed by the application at hand). The two functions
-    [outspace] and [outnewline] are normally connected to [out] and
-    [flush]: respective default values for [outspace] and [outnewline]
-    are [out (String.make n ' ') 0 n] and [out "\n" 0 1]. *)
-
-val get_all_formatter_output_functions :
-  unit ->
-  (string -> int -> int -> unit) *
-    (unit -> unit) *
-    (unit -> unit) *
-    (int -> unit)
-
-(** Return the current output functions of the pretty-printer,
-    including line breaking and indentation functions. Useful to record the
-    current setting and restore it afterwards. *)
+# 413 "src/batFormat.mliv"
+# 414 "src/batFormat.mliv"
+# 415 "src/batFormat.mliv"
+# 416 "src/batFormat.mliv"
+# 417 "src/batFormat.mliv"
+# 418 "src/batFormat.mliv"
+# 419 "src/batFormat.mliv"
+# 420 "src/batFormat.mliv"
+# 421 "src/batFormat.mliv"
+# 422 "src/batFormat.mliv"
 
 (** {6:tags Changing the meaning of printing semantics tags} *)
 
-type formatter_tag_functions = {
-  mark_open_tag : tag -> string;
-  mark_close_tag : tag -> string;
-  print_open_tag : tag -> unit;
-  print_close_tag : tag -> unit;
-}
+# 426 "src/batFormat.mliv"
+# 427 "src/batFormat.mliv"
+# 428 "src/batFormat.mliv"
+# 429 "src/batFormat.mliv"
+# 430 "src/batFormat.mliv"
+# 431 "src/batFormat.mliv"
 
-(** The tag handling functions specific to a formatter:
-    [mark] versions are the ``tag marking'' functions that associate a string
-    marker to a tag in order for the pretty-printing engine to flush
-    those markers as 0 length tokens in the output device of the formatter.
-    [print] versions are the ``tag printing'' functions that can perform
-    regular printing when a tag is closed or opened. *)
-
-val set_formatter_tag_functions :
-  formatter_tag_functions -> unit
-
-
-(** [set_formatter_tag_functions tag_funs] changes the meaning of
-    opening and closing tags to use the functions in [tag_funs].
-
-    When opening a tag name [t], the string [t] is passed to the
-    opening tag marking function (the [mark_open_tag] field of the
-    record [tag_funs]), that must return the opening tag marker for
-    that name. When the next call to [close_tag ()] happens, the tag
-    name [t] is sent back to the closing tag marking function (the
-    [mark_close_tag] field of record [tag_funs]), that must return a
-    closing tag marker for that name.
-
-    The [print_] field of the record contains the functions that are
-    called at tag opening and tag closing time, to output regular
-    material in the pretty-printer queue. *)
-
-val get_formatter_tag_functions :
-  unit -> formatter_tag_functions
+# 433 "src/batFormat.mliv"
+# 434 "src/batFormat.mliv"
+# 435 "src/batFormat.mliv"
+# 436 "src/batFormat.mliv"
+# 437 "src/batFormat.mliv"
+# 438 "src/batFormat.mliv"
+# 439 "src/batFormat.mliv"
+# 440 "src/batFormat.mliv"
+# 441 "src/batFormat.mliv"
+# 442 "src/batFormat.mliv"
+# 443 "src/batFormat.mliv"
+# 444 "src/batFormat.mliv"
+# 445 "src/batFormat.mliv"
+# 446 "src/batFormat.mliv"
+# 447 "src/batFormat.mliv"
+# 448 "src/batFormat.mliv"
+# 449 "src/batFormat.mliv"
+# 450 "src/batFormat.mliv"
+# 451 "src/batFormat.mliv"
+# 452 "src/batFormat.mliv"
+# 453 "src/batFormat.mliv"
+# 454 "src/batFormat.mliv"
+# 455 "src/batFormat.mliv"
+# 456 "src/batFormat.mliv"
+# 457 "src/batFormat.mliv"
+# 458 "src/batFormat.mliv"
+# 459 "src/batFormat.mliv"
+# 460 "src/batFormat.mliv"
 
 (** Return the current tag functions of the pretty-printer. *)
 
@@ -528,8 +528,8 @@ val pp_open_hvbox : formatter -> int -> unit
 val pp_open_hovbox : formatter -> int -> unit
 val pp_open_box : formatter -> int -> unit
 val pp_close_box : formatter -> unit -> unit
-val pp_open_tag : formatter -> string -> unit
-val pp_close_tag : formatter -> unit -> unit
+# 531 "src/batFormat.mliv"
+# 532 "src/batFormat.mliv"
 val pp_print_string : formatter -> string -> unit
 val pp_print_as : formatter -> int -> string -> unit
 val pp_print_int : formatter -> int -> unit
@@ -569,20 +569,20 @@ val pp_set_formatter_output_functions :
 val pp_get_formatter_output_functions :
   formatter -> unit -> (string -> int -> int -> unit) * (unit -> unit)
 
-val pp_set_all_formatter_output_functions :
-  formatter -> out:(string -> int -> int -> unit) -> flush:(unit -> unit) ->
-  newline:(unit -> unit) -> spaces:(int -> unit) -> unit
+# 572 "src/batFormat.mliv"
+# 573 "src/batFormat.mliv"
+# 574 "src/batFormat.mliv"
 
-val pp_get_all_formatter_output_functions :
-  formatter -> unit ->
-  (string -> int -> int -> unit) * (unit -> unit) * (unit -> unit) *
-    (int -> unit)
+# 576 "src/batFormat.mliv"
+# 577 "src/batFormat.mliv"
+# 578 "src/batFormat.mliv"
+# 579 "src/batFormat.mliv"
 
-val pp_set_formatter_tag_functions :
-  formatter -> formatter_tag_functions -> unit
+# 581 "src/batFormat.mliv"
+# 582 "src/batFormat.mliv"
 
-val pp_get_formatter_tag_functions :
-  formatter -> unit -> formatter_tag_functions
+# 584 "src/batFormat.mliv"
+# 585 "src/batFormat.mliv"
 
 (** These functions are the basic ones: usual functions
     operating on the standard formatter are defined via partial
@@ -731,15 +731,15 @@ val ksprintf : (string -> 'a) -> ('b, unit, string, 'a) format4 -> 'b
 
 (** {6 Deprecated} *)
 
-val bprintf : Buffer.t -> ('a, formatter, unit) format -> 'a
-(** A deprecated and error prone function. Do not use it.
+# 734 "src/batFormat.mliv"
+# 735 "src/batFormat.mliv"
+# 736 "src/batFormat.mliv"
+# 737 "src/batFormat.mliv"
+# 738 "src/batFormat.mliv"
+# 739 "src/batFormat.mliv"
 
-    If you need to print to some buffer [b], you must first define a
-    formatter writing to [b], using [let to_b = formatter_of_buffer b]; then
-    use regular calls to [Format.fprintf] on formatter [to_b]. *)
-
-val kprintf : (string -> 'a) -> ('b, unit, string, 'a) format4 -> 'b
-(** A deprecated synonym for [ksprintf]. *)
+# 741 "src/batFormat.mliv"
+# 742 "src/batFormat.mliv"
 
 (** {6 Basic functions to use with formatters} *)
 
