@@ -105,17 +105,17 @@ type stat = Gc.stat =
 
 type control = Gc.control =
   {
- mutable
+# 108 "src/batGc.mliv"
       minor_heap_size : int;
     (** The size (in words) of the minor heap.  Changing
         this parameter will trigger a minor collection.  Default: 32k. *)
 
- mutable
+# 113 "src/batGc.mliv"
       major_heap_increment : int;
     (** The minimum number of words to add to the
         major heap when increasing it.  Default: 124k. *)
 
- mutable
+# 118 "src/batGc.mliv"
       space_overhead : int;
     (** The major GC speed is computed from this parameter.
         This is the memory that will be "wasted" because the GC does not
@@ -125,7 +125,7 @@ type control = Gc.control =
         blocks more eagerly) if [space_overhead] is smaller.
         Default: 80. *)
 
- mutable
+# 128 "src/batGc.mliv"
       verbose : int;
     (** This value controls the GC messages on standard error output.
         It is a sum of some of the following flags, to print messages
@@ -142,7 +142,7 @@ type control = Gc.control =
         - [0x200] Computation of compaction triggering condition.
         Default: 0. *)
 
- mutable
+# 145 "src/batGc.mliv"
       max_overhead : int;
     (** Heap compaction is triggered when the estimated amount
         of "wasted" memory is more than [max_overhead] percent of the
@@ -152,13 +152,13 @@ type control = Gc.control =
         If [max_overhead >= 1000000], compaction is never triggered.
         Default: 500. *)
 
- mutable
+# 155 "src/batGc.mliv"
       stack_limit : int;
     (** The maximum size of the stack (in words).  This is only
         relevant to the byte-code runtime, as the native code runtime
         uses the operating system's stack.  Default: 256k. *)
 
- mutable
+# 161 "src/batGc.mliv"
       allocation_policy : int;
     (** The policy used for allocating in the heap.  Possible
         values are 0 and 1.  0 is the next-fit policy, which is
@@ -282,23 +282,23 @@ external get_minor_free : unit -> int = "caml_get_minor_free"
 (** Return the current size of the free space inside the minor heap.
     @since 2.5.0 and OCaml 4.03.0 *)
 
-external get_bucket : int -> int = "caml_get_major_bucket" [@@noalloc]
-(** [get_bucket n] returns the current size of the [n]-th future bucket
-    of the GC smoothing system. The unit is one millionth of a full GC.
-    Raise [Invalid_argument] if [n] is negative, return 0 if n is larger
-    than the smoothing window.
-    @since 2.5.0 and OCaml 4.03.0 *)
+# 285 "src/batGc.mliv"
+# 286 "src/batGc.mliv"
+# 287 "src/batGc.mliv"
+# 288 "src/batGc.mliv"
+# 289 "src/batGc.mliv"
+# 290 "src/batGc.mliv"
 
-external get_credit : unit -> int = "caml_get_major_credit" [@@noalloc]
-(** [get_credit ()] returns the current size of the "work done in advance"
-    counter of the GC smoothing system. The unit is one millionth of a
-    full GC.
-    @since 2.5.0 and OCaml 4.03.0 *)
+# 292 "src/batGc.mliv"
+# 293 "src/batGc.mliv"
+# 294 "src/batGc.mliv"
+# 295 "src/batGc.mliv"
+# 296 "src/batGc.mliv"
 
-external huge_fallback_count : unit -> int = "caml_gc_huge_fallback_count"
-(** Return the number of times we tried to map huge pages and had to fall
-    back to small pages. This is always 0 if [OCAMLRUNPARAM] contains [H=1].
-    @since 2.5.0 and OCaml 4.03.0 *)
+# 298 "src/batGc.mliv"
+# 299 "src/batGc.mliv"
+# 300 "src/batGc.mliv"
+# 301 "src/batGc.mliv"
 
 val finalise : ('a -> unit) -> 'a -> unit
 (** [finalise f v] registers [f] as a finalisation function for [v].
@@ -392,8 +392,8 @@ val delete_alarm : alarm -> unit
   (** [delete_alarm a] will stop the calls to the function associated
       to [a].  Calling [delete_alarm a] again has no effect. *)
 
-external eventlog_pause : unit -> unit = "caml_eventlog_pause"
-# 396 "src/batGc.mliv"
+# 395 "src/batGc.mliv"
+val                eventlog_pause : unit -> unit
 (** [eventlog_pause ()] will pause the collection of traces in the
    runtime.
    Traces are collected if the program is linked to the instrumented runtime
@@ -401,8 +401,8 @@ external eventlog_pause : unit -> unit = "caml_eventlog_pause"
    Events are flushed to disk after pausing, and no new events will be
    recorded until [eventlog_resume] is called. *)
 
-external eventlog_resume : unit -> unit = "caml_eventlog_resume"
-# 405 "src/batGc.mliv"
+# 404 "src/batGc.mliv"
+val                eventlog_resume : unit -> unit
 (** [eventlog_resume ()] will resume the collection of traces in the
    runtime.
    Traces are collected if the program is linked to the instrumented runtime
