@@ -22,7 +22,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *)
 
-# 25 "src/batList.mliv"
+module Pervasives := Stdlib
 
 (** Additional and modified functions for lists.
 
