@@ -20,7 +20,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *)
 
-# 23 "src/batMap.mliv"
+module Pervasives := Stdlib
 
 (** Association tables over ordered types.
 
