@@ -32,7 +32,7 @@
 
 open BatIO
 
-# 35 "src/batPervasives.mliv"
+ module Pervasives := Stdlib
 
 (** The initially opened module.
 
