@@ -382,18 +382,18 @@ val bscanf : Scanning.scanbuf -> ('a, 'b, 'c, 'd) scanner
 
 (** {6 Specialized formatted input functions} *)
 
-val fscanf : in_channel -> ('a, 'b, 'c, 'd) scanner
-(** Same as {!Scanf.bscanf}, but reads from the given channel.
-
-    Warning: since all formatted input functions operate from a scanning
-    buffer, be aware that each [fscanf] invocation will operate with a
-    scanning buffer reading from the given channel. This extra level of
-    bufferization can lead to strange scanning behaviour if you use low level
-    primitives on the channel (reading characters, seeking the reading
-    position, and so on).
-
-    As a consequence, never mixt direct low level reading and high level
-    scanning from the same input channel. *)
+# 385 "src/batScanf.mliv"
+# 386 "src/batScanf.mliv"
+# 387 "src/batScanf.mliv"
+# 388 "src/batScanf.mliv"
+# 389 "src/batScanf.mliv"
+# 390 "src/batScanf.mliv"
+# 391 "src/batScanf.mliv"
+# 392 "src/batScanf.mliv"
+# 393 "src/batScanf.mliv"
+# 394 "src/batScanf.mliv"
+# 395 "src/batScanf.mliv"
+# 396 "src/batScanf.mliv"
 
 val sscanf : string -> ('a, 'b, 'c, 'd) scanner
 (** Same as {!Scanf.bscanf}, but reads from the given string. *)
