@@ -101,18 +101,18 @@ external get : string -> int -> char = "%string_safe_get"
     @raise Invalid_argument if [n] not a valid character number in [s]. *)
 
 
-external set : Bytes.t -> int -> char -> unit = "%string_safe_set"
-(** [String.set s n c] modifies string [s] in place,
-    replacing the character number [n] by [c].
-    You can also write [s.[n] <- c] instead of [String.set s n c].
+# 104 "src/batString.mliv"
+# 105 "src/batString.mliv"
+# 106 "src/batString.mliv"
+# 107 "src/batString.mliv"
+# 108 "src/batString.mliv"
+# 109 "src/batString.mliv"
 
-    @raise Invalid_argument if [n] is not a valid character number in [s]. *)
-
-external create : int -> Bytes.t = "caml_create_string"
-(** [String.create n] returns a fresh string of length [n].
-    The string initially contains arbitrary characters.
-
-    @raise Invalid_argument if [n < 0] or [n > ]{!Sys.max_string_length}. *)
+# 111 "src/batString.mliv"
+# 112 "src/batString.mliv"
+# 113 "src/batString.mliv"
+# 114 "src/batString.mliv"
+# 115 "src/batString.mliv"
 
 val make : int -> char -> string
 (** [String.make n c] returns a fresh string of length [n],
@@ -120,8 +120,8 @@ val make : int -> char -> string
 
     @raise Invalid_argument if [n < 0] or [n > ]{!Sys.max_string_length}.*)
 
-val copy : string -> string
-(** Return a copy of the given string. *)
+# 123 "src/batString.mliv"
+# 124 "src/batString.mliv"
 
 val sub : string -> int -> int -> string
 (** [String.sub s start len] returns a fresh string of length [len],
@@ -131,12 +131,12 @@ val sub : string -> int -> int -> string
     @raise Invalid_argument if [start] and [len] do not
     designate a valid substring of [s]. *)
 
-val fill : Bytes.t -> int -> int -> char -> unit
-(** [String.fill s start len c] modifies the byte sequence [s] in
-    place, replacing [len] characters by [c], starting at [start].
-
-    @raise Invalid_argument if [start] and [len] do not
-    designate a valid substring of [s]. *)
+# 134 "src/batString.mliv"
+# 135 "src/batString.mliv"
+# 136 "src/batString.mliv"
+# 137 "src/batString.mliv"
+# 138 "src/batString.mliv"
+# 139 "src/batString.mliv"
 
 val blit : string -> int -> Bytes.t -> int -> int -> unit
 (** [String.blit src srcoff dst dstoff len] copies [len] characters
@@ -292,21 +292,21 @@ val rcontains_from : string -> int -> char -> bool
     @raise Invalid_argument if [stop < 0] or [stop+1] is not a valid
     position in [s]. *)
 
-val uppercase : string -> string
-(** Return a copy of the argument, with all lowercase letters
-    translated to uppercase, including accented letters of the ISO
-    Latin-1 (8859-1) character set. *)
+# 295 "src/batString.mliv"
+# 296 "src/batString.mliv"
+# 297 "src/batString.mliv"
+# 298 "src/batString.mliv"
 
-val lowercase : string -> string
-(** Return a copy of the argument, with all uppercase letters
-    translated to lowercase, including accented letters of the ISO
-    Latin-1 (8859-1) character set. *)
+# 300 "src/batString.mliv"
+# 301 "src/batString.mliv"
+# 302 "src/batString.mliv"
+# 303 "src/batString.mliv"
 
-val capitalize : string -> string
-(** Return a copy of the argument, with the first character set to uppercase. *)
-
-val uncapitalize : string -> string
-(** Return a copy of the argument, with the first character set to lowercase. *)
+# 305 "src/batString.mliv"
+# 306 "src/batString.mliv"
+# 307 "src/batString.mliv"
+# 308 "src/batString.mliv"
+# 309 "src/batString.mliv"
 
 val uppercase_ascii : string -> string
 (** Return a copy of the argument, with all lowercase letters
@@ -955,19 +955,19 @@ val get_int32_ne : string -> int -> int32
     starting at character index [i].
     @since 3.4.0 and OCaml 4.08 *)
 
-# 958 "src/batString.mliv"
-# 959 "src/batString.mliv"
-# 960 "src/batString.mliv"
-# 961 "src/batString.mliv"
-# 962 "src/batString.mliv"
-# 963 "src/batString.mliv"
+val hash : t -> int
+(** An unseeded hash function for strings, with the same output value as
+    {!Hashtbl.hash}. This function allows this module to be passed as argument
+    to the functor {!Hashtbl.Make}.
 
-# 965 "src/batString.mliv"
-# 966 "src/batString.mliv"
-# 967 "src/batString.mliv"
-# 968 "src/batString.mliv"
-# 969 "src/batString.mliv"
-# 970 "src/batString.mliv"
+    @since 3.6.0 and OCaml 5.0.0 *)
+
+val seeded_hash : int -> t -> int
+(** A seeded hash function for strings, with the same output value as
+    {!Hashtbl.seeded_hash}. This function allows this module to be passed as
+    argument to the functor {!Hashtbl.MakeSeeded}.
+
+    @since 3.6.0 and OCaml 5.0.0 *)
 
 val get_int32_be : string -> int -> int32
 (** [get_int32_be b i] is [b]'s big-endian 32-bit integer
@@ -1387,10 +1387,10 @@ sig
 
   val strip : ?chars:[> `Read] t -> [> `Read] t -> _ t
 
- val uppercase : [> `Read] t -> _ t
- val lowercase : [> `Read] t -> _ t
- val capitalize : [> `Read] t -> _ t
- val uncapitalize : [> `Read] t -> _ t
+# 1390 "src/batString.mliv"
+# 1391 "src/batString.mliv"
+# 1392 "src/batString.mliv"
+# 1393 "src/batString.mliv"
 
   val copy : [> `Read] t -> _ t
 
@@ -1497,14 +1497,14 @@ end
 (* The following is for system use only. Do not call directly. *)
 
 external unsafe_get : string -> int -> char = "%string_unsafe_get"
-external unsafe_set : Bytes.t -> int -> char -> unit = "%string_unsafe_set"
+# 1500 "src/batString.mliv"
 external unsafe_blit :
   string -> int -> Bytes.t -> int -> int -> unit = "caml_blit_string"
 # 1503 "src/batString.mliv"
   [@@noalloc]
-external unsafe_fill :
-  Bytes.t -> int -> int -> char -> unit = "caml_fill_string"
+# 1505 "src/batString.mliv"
+# 1506 "src/batString.mliv"
 # 1507 "src/batString.mliv"
-  [@@noalloc]
+# 1508 "src/batString.mliv"
 
   (**/**)
